@@ -25,7 +25,7 @@ from ztfy.security.schema import IPrincipal
 
 # import Zope3 packages
 from zope.interface import Attribute
-from zope.schema import Object, List
+from zope.schema import Object, List, Bool
 
 # import local packages
 
@@ -56,3 +56,7 @@ class IPrincipalListWidget(ITextWidget):
                       value_type=Object(schema=IPrincipal))
 
     principals_map = Attribute(_("Principals map"))
+
+    backspace_removes_last = Bool(title=_("Backspace key removes last value?"),
+                                  required=True,
+                                  default=True)
